@@ -1,5 +1,6 @@
 import requests
 import ujson as json
+from .lib import ValueModel
 
 class Client:
     def __init__(self, token: str, debug: bool = False):
@@ -21,4 +22,12 @@ class Client:
         if self.debug:
             self.__log(res.text)
 
-        return json.loads(res.text)
\ No newline at end of file
+        bd = json.loads(res.text)
+
+        if bd["code"] != 200:
+            raise Exception(f"BotDash Error: [{bd['code']}] {bd['msg']}")
+        else: 
+            return ValueModel(bd)
+        
+
+        
